@@ -1,14 +1,19 @@
 #!/usr/bin/perl -w
 
-# $Id: setup.pl,v 1.5 2004/03/30 08:45:53 jonasbn Exp $
+# $Id: setup.pl,v 1.7 2004/03/31 10:48:55 jonasbn Exp $
 
 use strict;
+use Env qw(HOME);
 use lib qw(lib ../lib);
-use Module::Template::Setup qw(setup);
+use Module::Template::Setup;
 
 my $modulename = $ARGV[0];
 
-setup($modulename);
+my $mts = Module::Template::Setup->new(
+	modulename => $modulename,
+	configfile => "$HOME/.mts/mts.ini"
+);
+$mts->setup();
 
 exit(0);
 
